@@ -18,7 +18,9 @@ def testing():
                 
     print(sector_news)
     
-testing()
+googlenews = GoogleNews(lang='en', period='14d') # Specify period for news
+googlenews.get_news('MARA')
+print(googlenews.results())
 
 # googlenews = GoogleNews(lang='en', period='14d') # Specify period for news
 # googlenews.get_news('Semiconductors')
